emoji-data
==========

:Release: |release|
:Version: |version|
:Date:    |today|

Contents
--------

.. toctree::
   :caption: Documentations
   :titlesonly:

   README <README>
   CHANGELOG
   AUTHORS

.. toctree::
    :caption: API References

    modules

.. toctree::
   :caption: Notebooks
   :glob:
   :titlesonly:

   notebooks/*

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
